.. include:: globals.rst

.. include:: ../README.txt


.. toctree::
   :maxdepth: 2

   install
   upload
   pip
   settings
   permissions
   server
   changes

.. toctree::
    :hidden:

    globals
